@@ -18,7 +18,7 @@ static void fs_open(char* device);
 static void fs_close();
 
 ///  readbitmap - read bitmap
-extern void readbitmap(char* device, image_head image_hdr, char* bitmap, int pui);
+extern void readbitmap(char* device, image_head image_hdr, unsigned long* bitmap, int pui);
 
 /// read super block and write to image head
 extern void initial_image_hdr(char* device, image_head* image_hdr);
