@@ -39,7 +39,7 @@ unsigned int    source_sectorsize;      /* source disk sectorsize */
 
 #define rounddown(x, y) (((x)/(y))*(y))
 
-static void set_bitmap(char* bitmap, uint64_t pos, int length)
+static void set_bitmap(unsigned long* bitmap, uint64_t pos, int length)
 {
     uint64_t pos_block;
     uint64_t block_count;
@@ -49,7 +49,7 @@ static void set_bitmap(char* bitmap, uint64_t pos, int length)
     block_count = length/source_blocksize;
 
     for (block = pos_block; block < pos_block+block_count; block++){
-	bitmap[block] = 1;
+	pc_set_bit(block, bitmap);
 	log_mesg(3, 0, 0, fs_opt.debug, "block %i is used\n", block);
     }
 
@@ -166,7 +166,7 @@ extern void initial_image_hdr(char* device, image_head* image_hdr)
 
 }
 
-extern void readbitmap(char* device, image_head image_hdr, char* bitmap, int pui)
+extern void readbitmap(char* device, image_head image_hdr, unsigned long* bitmap, int pui)
 {
 
     xfs_agnumber_t  agno = 0;
@@ -203,7 +203,7 @@ extern void readbitmap(char* device, image_head image_hdr, char* bitmap, int pui
     int		    log_length;
 
     struct xfs_btree_block *block;
-    uint64_t current_block, block_count;
+    uint64_t current_block, block_count, prog_cur_block = 0;
 
     int start = 0;
     int bit_size = 1;
@@ -213,7 +213,7 @@ extern void readbitmap(char* device, image_head image_hdr, char* bitmap, int pui
     uint64_t bfree = 0;
 
     /// init progress
-    progress_init(&prog, start, image_hdr.totalblock, bit_size);
+    progress_init(&prog, start, image_hdr.totalblock, image_hdr.totalblock, BITMAP, bit_size);
 
     fs_open(device);
 
@@ -466,11 +466,12 @@ extern void readbitmap(char* device, image_head image_hdr, char* bitmap, int pui
 
 	log_mesg(2, 0, 0, fs_opt.debug, "write a clean log done\n");
 
-	update_pui(&prog, (image_hdr.totalblock/num_ags*(agno+1)-1), 0);
+	prog_cur_block = image_hdr.totalblock/num_ags*(agno+1)-1;
+	update_pui(&prog, prog_cur_block, prog_cur_block, 0);
     }
 
     for(current_block = 0; current_block <= image_hdr.totalblock; current_block++){
-	if(bitmap[current_block] == 1)
+	if(pc_test_bit(current_block, bitmap))
 	    bused++;
 	else
 	    bfree++;
@@ -478,7 +479,7 @@ extern void readbitmap(char* device, image_head image_hdr, char* bitmap, int pui
     log_mesg(0, 0, 0, fs_opt.debug, "bused = %lli, bfree = %lli\n", bused, bfree);
 
     fs_close();
-    update_pui(&prog, 1, 1);
+    update_pui(&prog, 1, 1, 1);
 
 }
 
